==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Lhet");
define("_URL","URL");
define("_PRINTER","Kevyempi versio tulostusta varten");
define("_FRIEND","Lhet ystvlle");
define("_YOURNAME","Nimesi");
define("_OK","Ok!");
define("_RELATED","Linkkej"); 
define("_MOREABOUT","Enemmn aiheesta"); 
define("_NEWSBY","Uutiset"); 
define("_MOSTREAD","Luetuin tarina aiheesta"); 
define("_READMORE","Lue lis..."); 
define("_BYTESMORE","tavua enemmn"); 
define("_COMMENTSQ","kommentteja?"); 
define("_COMMENT","kommentti"); 
 
define("_CONFIGURE","Muokkaa");
define("_LOGINCREATE","Kirjaudu/Rekisteridy");
define("_THRESHOLD","Pisteet");
define("_NOCOMMENTS","Ei kommentteja");
define("_NESTED","Sisennetty nkym");
define("_FLAT","Allekkainen nkym");
define("_THREAD","Puu");
define("_OLDEST","Vanhimmat eka");
define("_NEWEST","Uusimmat eka");
define("_HIGHEST","Parhaat pisteet eka");
define("_COMMENTSWARNING","Kommentit ovat kyttjien omia - me emme ole niist missn vastuussa.");
define("_SCORE","Pisteet:");
define("_USERINFO","Kyttjn tiedot");
define("_READREST","Lue kommentista loputkin...");
define("_REPLY","Vastaa");
define("_REPLYMAIN","Lhet kommentti");
define("_NOSUBJECT","Ei aihetta");
define("_NOANONCOMMENTS","Anonyymi ei saa antaa kommentteja...ole hyv ja <a href=\"user.php\">rekisteridy</a>");
define("_PARENT","rinnakkainen");
define("_ROOT","Root");
define("_UCOMMENT","Kommenttia");
define("_ALLOWEDHTML","HTML sallittu:");
define("_POSTANON","Kirjoita anonyymisti");
define("_EXTRANS","Lis html tagit tekstiin");
define("_HTMLFORMATED","HTML formatoituna");
define("_PLAINTEXT","Pelkkn tekstin");
define("_ONN","on...");
define("_SUBJECT","Aihe");
define("_COMMENTREPLY","Lhet");
define("_COMREPLYPRE","Esikatsele");
define("_NOTRIGHT","Joku nyt ei ole vaan oikein - ota yhteytt yllpitoon jos tilanne vain jatkuu");
define("_SENDAMSG","Lhet viesti");
define("_YOUSENDSTORY","Suosittelet artikkelia:");
define("_TOAFRIEND","Kaverillesi:");
define("_FYOURNAME","Nimesi:");
define("_FYOUREMAIL","Shkpostiosoitteesi:");
define("_FFRIENDNAME","Kaverisi nimi:");
define("_FFRIENDEMAIL","Kaverisi shkpostiosoite:");
define("_INTERESTING","Mielenkiintoinen artikkeli");
define("_HELLO","Hei");
define("_YOURFRIEND","ystvsi");
define("_CONSIDERED","luki linkin artikkelin ja ajatteli, ett tm on just sinulle sopiva artikkeli.");
define("_FDATE","Piv:");
define("_FTOPIC","Aihe:");
define("_YOUCANREAD","Voit lukea muita artikkeleita osoitteesta");
define("_FSTORY","Artikkeli");
define("_HASSENT","on lhetty:");
define("_THANKS","Kiitos!");
define("_RECOMMEND","Suosittele sivustoa kaverillesi");
define("_PDATE","Piv:");
define("_PTOPIC","Aihe:");
define("_COMESFROM","Artikkelin lde");
define("_THEURL","Artikkelin URL:");
define("_PREVIEW","Esikatsele");
define("_NEWUSER","Uusi kyttj");
define("_OPTIONS","Ominaisuudet");
define("_REFRESH","Pivit");
define("_ADD","Lis");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Lhet");
define("_URL","URL");
define("_PRINTER","Kevyempi versio tulostusta varten");
define("_FRIEND","Lhet ystvlle");
define("_YOURNAME","Nimesi");
define("_OK","Ok!");
define("_RELATED","Linkkej"); 
define("_MOREABOUT","Enemmn aiheesta"); 
define("_NEWSBY","Uutiset"); 
define("_MOSTREAD","Luetuin tarina aiheesta"); 
define("_READMORE","Lue lis..."); 
define("_BYTESMORE","tavua enemmn"); 
define("_COMMENTSQ","kommentteja?"); 
define("_COMMENT","kommentti"); 
 
define("_CONFIGURE","Muokkaa");
define("_LOGINCREATE","Kirjaudu/Rekisteridy");
define("_THRESHOLD","Pisteet");
define("_NOCOMMENTS","Ei kommentteja");
define("_NESTED","Sisennetty nkym");
define("_FLAT","Allekkainen nkym");
define("_THREAD","Puu");
define("_OLDEST","Vanhimmat eka");
define("_NEWEST","Uusimmat eka");
define("_HIGHEST","Parhaat pisteet eka");
define("_COMMENTSWARNING","Kommentit ovat kyttjien omia - me emme ole niist missn vastuussa.");
define("_SCORE","Pisteet:");
define("_USERINFO","Kyttjn tiedot");
define("_READREST","Lue kommentista loputkin...");
define("_REPLY","Vastaa");
define("_REPLYMAIN","Lhet kommentti");
define("_NOSUBJECT","Ei aihetta");
define("_NOANONCOMMENTS","Anonyymi ei saa antaa kommentteja...ole hyv ja <a href=\"user.php\">rekisteridy</a>");
define("_PARENT","rinnakkainen");
define("_ROOT","Root");
define("_UCOMMENT","Kommenttia");
define("_ALLOWEDHTML","HTML sallittu:");
define("_POSTANON","Kirjoita anonyymisti");
define("_EXTRANS","Lis html tagit tekstiin");
define("_HTMLFORMATED","HTML formatoituna");
define("_PLAINTEXT","Pelkkn tekstin");
define("_ONN","on...");
define("_SUBJECT","Aihe");
define("_COMMENTREPLY","Lhet");
define("_COMREPLYPRE","Esikatsele");
define("_NOTRIGHT","Joku nyt ei ole vaan oikein - ota yhteytt yllpitoon jos tilanne vain jatkuu");
define("_SENDAMSG","Lhet viesti");
define("_YOUSENDSTORY","Suosittelet artikkelia:");
define("_TOAFRIEND","Kaverillesi:");
define("_FYOURNAME","Nimesi:");
define("_FYOUREMAIL","Shkpostiosoitteesi:");
define("_FFRIENDNAME","Kaverisi nimi:");
define("_FFRIENDEMAIL","Kaverisi shkpostiosoite:");
define("_INTERESTING","Mielenkiintoinen artikkeli");
define("_HELLO","Hei");
define("_YOURFRIEND","ystvsi");
define("_CONSIDERED","luki linkin artikkelin ja ajatteli, ett tm on just sinulle sopiva artikkeli.");
define("_FDATE","Piv:");
define("_FTOPIC","Aihe:");
define("_YOUCANREAD","Voit lukea muita artikkeleita osoitteesta");
define("_FSTORY","Artikkeli");
define("_HASSENT","on lhetty:");
define("_THANKS","Kiitos!");
define("_RECOMMEND","Suosittele sivustoa kaverillesi");
define("_PDATE","Piv:");
define("_PTOPIC","Aihe:");
define("_COMESFROM","Artikkelin lde");
define("_THEURL","Artikkelin URL:");
define("_PREVIEW","Esikatsele");
define("_NEWUSER","Uusi kyttj");
define("_OPTIONS","Ominaisuudet");
define("_REFRESH","Pivit");
define("_ADD","Lis");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
